@@ -5,6 +5,7 @@ import configparser
 import os
 import yaml
 
+from qgispluginci.changelog import ChangelogParser
 from qgispluginci.exceptions import ConfigurationNotFound
 from qgispluginci.release import release
 from qgispluginci.translation import Translation
@@ -32,6 +33,14 @@ def main():
         help='If omitted, uncommitted changes are not allowed before packaging. If specified and some changes are '
              'detected, a hard reset on a stash create will be used to revert changes made by qgis-plugin-ci.'
     )
+    package_parser.add_argument(
+        '--disable-submodule-update', action='store_true',
+        help='If omitted, a git submodule is updated. If specified, git submodules will not be updated/initialized before packaging.'
+    )
+
+    # changelog
+    changelog_parser = subparsers.add_parser('changelog', help='gets the changelog content')
+    changelog_parser.add_argument('release_version', help='The version to be released')
 
     # release
     release_parser = subparsers.add_parser('release', help='release the plugin')
@@ -53,6 +62,10 @@ def main():
         help='If omitted, uncommitted changes are not allowed before releasing. If specified and some changes are '
              'detected, a hard reset on a stash create will be used to revert changes made by qgis-plugin-ci.'
     )
+    release_parser.add_argument(
+        '--disable-submodule-update', action='store_true',
+        help='If omitted, a git submodule is updated. If specified, git submodules will not be updated/initialized before packaging.'
+    )
     release_parser.add_argument('--osgeo-username', help='The Osgeo user name to publish the plugin.')
     release_parser.add_argument('--osgeo-password', help='The Osgeo password to publish the plugin.')
 
@@ -103,6 +116,7 @@ def main():
             transifex_token=args.transifex_token,
             allow_uncommitted_changes=args.allow_uncommitted_changes,
             plugin_repo_url=args.plugin_repo_url,
+            disable_submodule_update=args.disable_submodule_update,
         )
 
     # RELEASE
@@ -116,8 +130,20 @@ def main():
             osgeo_username=args.osgeo_username,
             osgeo_password=args.osgeo_password,
             allow_uncommitted_changes=args.allow_uncommitted_changes,
+            disable_submodule_update=args.disable_submodule_update,
         )
 
+    # CHANGELOG
+    elif args.command == 'changelog':
+        try:
+            c = ChangelogParser(parameters.changelog_regexp)
+            content = c.content(args.release_version)
+            if content:
+                print(content)
+        except Exception:
+            # Better to be safe
+            pass
+
     # TRANSLATION PULL
     elif args.command == 'pull-translation':
         t = Translation(parameters, args.transifex_token)
